diff --git a/src/main/java/eu/m724/blog/BlogBuilder.java b/src/main/java/eu/m724/blog/BlogBuilder.java
index 2c80446..b793f3d 100644
--- a/src/main/java/eu/m724/blog/BlogBuilder.java
+++ b/src/main/java/eu/m724/blog/BlogBuilder.java
@@ -124,7 +124,7 @@ public class BlogBuilder {
}
/**
- * Builds the blog by generating templates, copying assets, and rendering posts.
+ * Builds the blog by generating templates, copying assets, and rendering articles.
*
* @throws IOException if an I/O error occurs
*/
diff --git a/src/main/java/eu/m724/blog/object/Feed.java b/src/main/java/eu/m724/blog/object/Feed.java
index 744748e..14deafd 100644
--- a/src/main/java/eu/m724/blog/object/Feed.java
+++ b/src/main/java/eu/m724/blog/object/Feed.java
@@ -13,11 +13,11 @@ public class Feed {
private static final DateTimeFormatter formatter = DateTimeFormatter.ofPattern("EEE, dd MMM yyyy HH:mm:ss zzz");
/**
- * Generates an RSS feed XML string for a given website and its list of blog posts.
+ * Generates an XML RSS feed for the site and its articles.
*
- * @param site the {@code Site} object representing the website for which the RSS feed is generated
- * @param articles the list of {@link Article} objects representing the blog posts to include in the RSS feed
- * @return a {@code String} containing the formatted RSS feed in XML
+ * @param site the {@link Site} object representing the website for which the RSS feed is generated
+ * @param articles the list of {@link Article} objects representing the articles to include in the RSS feed
+ * @return a {@link String} containing the formatted RSS feed in XML
*/
public static String generateRss(Site site, List articles) {
var content = new StringBuilder("");
diff --git a/src/main/java/eu/m724/blog/object/Site.java b/src/main/java/eu/m724/blog/object/Site.java
index ceb4f20..4bb96ed 100644
--- a/src/main/java/eu/m724/blog/object/Site.java
+++ b/src/main/java/eu/m724/blog/object/Site.java
@@ -20,7 +20,7 @@ import java.util.Map;
* @param name the name of the site
* @param baseUrl the base URL of the site
* @param directory The directory that the site is installed into. Like "https://example.com/blog" turns to "/blog"
- * @param templateArticles whether to parse posts with Pebble templating
+ * @param templateArticles whether to parse articles with Pebble templating
* @param custom a map of additional custom properties
*/
public record Site(
diff --git a/src/main/java/eu/m724/blog/template/TemplateRenderer.java b/src/main/java/eu/m724/blog/template/TemplateRenderer.java
index 144fbc7..54d473c 100644
--- a/src/main/java/eu/m724/blog/template/TemplateRenderer.java
+++ b/src/main/java/eu/m724/blog/template/TemplateRenderer.java
@@ -66,10 +66,10 @@ public class TemplateRenderer {
}
/**
- * Renders the content of a post using this template.
+ * Renders the content of an article using this template.
*
* @param article the {@link Article} to be rendered
- * @return the rendered post HTML page as a string
+ * @return the rendered article HTML page as a string
* @throws IOException if an error occurs during template evaluation
*/
public String renderArticle(Article article) throws IOException {
diff --git a/src/main/java/eu/m724/blog/object/Article.java b/src/main/java/eu/m724/blog/object/Article.java
index 24435be..83c8bfb 100644
--- a/src/main/java/eu/m724/blog/object/Article.java
+++ b/src/main/java/eu/m724/blog/object/Article.java
@@ -19,19 +19,19 @@ import java.util.HashMap;
import java.util.Map;
/**
- * The {@code Article} class represents a blog post with various attributes including metadata and content.
+ * The {@code Article} class represents an article with various attributes including metadata and content.
*
* @param slug A unique identifier for the post derived from the file name.
* @param title The title of the post.
* @param summary A brief summary of the post content.
* @param draft Indicates whether the post is marked as a draft or published.
* @param revisions The number of revisions the post has undergone in version control.
* @param createdBy The name of the author who created the post.
* @param createdAt The timestamp of when the post was first created.
* @param modifiedBy The name of the author who last modified the post.
* @param modifiedAt The timestamp of the last modification to the post.
* @param custom A map of custom properties or metadata associated with the post.
* @param rawContent The raw content of the post, which currently is usually HTML.
*/
public record Article(
String slug,
@@ -104,7 +104,7 @@ public record Article(
case "summary":
summary = value;
break;
- case "live": // a post is live (not draft) if the key is there
+ case "live": // an article is live (not draft) if the key is there
draft = false;
break;
default:
@@ -19,19 +19,19 @@ import java.util.HashMap;
*
- * @param slug A unique identifier for the post derived from the file name.
- * @param title The title of the post.
- * @param summary A brief summary of the post content.
- * @param draft Indicates whether the post is marked as a draft or published.
- * @param revisions The number of revisions the post has undergone in version control.
- * @param createdBy The name of the author who created the post.
- * @param createdAt The timestamp of when the post was first created.
- * @param modifiedBy The name of the author who last modified the post.
- * @param modifiedAt The timestamp of the last modification to the post.
- * @param custom A map of custom properties or metadata associated with the post.
- * @param rawContent The raw content of the post, which currently is usually HTML.
+ * @param slug A unique identifier for the article derived from the file name.
+ * @param title The title of the article.
+ * @param summary A brief summary of the article content.
+ * @param draft Indicates whether the article is marked as a draft or published.
+ * @param revisions The number of revisions the article has undergone in version control.
+ * @param createdBy The name of the author who created the article.
+ * @param createdAt The timestamp of when the article was first created.
+ * @param modifiedBy The name of the author who last modified the article.
+ * @param modifiedAt The timestamp of the last modification to the article.
+ * @param custom A map of custom properties or metadata associated with the article.
+ * @param rawContent The raw content of the article, which currently is usually HTML.
*/
public record Article(